@@ -34,7 +34,7 @@
 ///        each buffer swap.
 
 #define _POSIX_C_SOURCE 199309L // glibc feature macro for nanosleep.
-#define WAFFLE_API_VERSION 0x0106
+#define WAFFLE_API_VERSION 0x0108
 #define WAFFLE_API_EXPERIMENTAL
 
 #include <assert.h>
@@ -132,8 +132,16 @@ static const struct option get_opts[] = {
 #define NORETURN
 #endif
 
-static void NORETURN
+#if defined(__GNUC__)
+#define PRINTFLIKE(f, a) __attribute__((format(gnu_printf, f, a)))
+#else
+#define PRINTFLIKE(f, a)
+#endif
+
+// clang-format off
+static void NORETURN PRINTFLIKE(1, 2)
 error_printf(const char *fmt, ...)
+// clang-format on
 {
     va_list ap;
 
@@ -148,8 +156,10 @@ error_printf(const char *fmt, ...)
     exit(EXIT_FAILURE);
 }
 
-static void NORETURN
+// clang-format off
+static void NORETURN PRINTFLIKE(1, 2)
 usage_error_printf(const char *fmt, ...)
+// clang-format on
 {
     fflush(stdout);
     fprintf(stderr, "gl_basic: usage error");
@@ -169,7 +179,7 @@ usage_error_printf(const char *fmt, ...)
     exit(EXIT_FAILURE);
 }
 
-static void
+static void NORETURN
 error_waffle(void)
 {
     const struct waffle_error_info *info = waffle_error_get_info();
@@ -181,7 +191,7 @@ error_waffle(void)
         error_printf("%s", code);
 }
 
-static void
+static void NORETURN
 error_get_gl_symbol(const char *name)
 {
     error_printf("failed to get function pointer for %s", name);
