@@ -32,7 +32,7 @@
 ///     2. Create an OpenGL context.
 ///     3. Print information about the context.
 
-#define WAFFLE_API_VERSION 0x0106
+#define WAFFLE_API_VERSION 0x0108
 
 #include <assert.h>
 #include <ctype.h>
@@ -139,6 +139,12 @@ strneq(const char *a, const char *b, size_t n)
 #define NORETURN
 #endif
 
+#if defined(__GNUC__)
+#define PRINTFLIKE(f, a) __attribute__((format(gnu_printf, f, a)))
+#else
+#define PRINTFLIKE(f, a)
+#endif
+
 static void NORETURN
 error_oom(void)
 {
@@ -146,8 +152,8 @@ error_oom(void)
     exit(EXIT_FAILURE);
 }
 
-static void NORETURN
-error_printf(const char *module, const char *fmt, ...)
+static void NORETURN PRINTFLIKE(2, 3)
+    error_printf(const char *module, const char *fmt, ...)
 {
     va_list ap;
 
@@ -167,8 +173,10 @@ write_usage_and_exit(FILE *f, int exit_code)
     exit(exit_code);
 }
 
-static void NORETURN
+// clang-format off
+static void NORETURN PRINTFLIKE(1, 2)
 usage_error_printf(const char *fmt, ...)
+// clang-format on
 {
     fprintf(stderr, "Wflinfo usage error: ");
 
@@ -184,7 +192,7 @@ usage_error_printf(const char *fmt, ...)
     exit(EXIT_FAILURE);
 }
 
-static void
+static void NORETURN
 error_waffle(void)
 {
     const struct waffle_error_info *info = waffle_error_get_info();
@@ -196,7 +204,7 @@ error_waffle(void)
         error_printf("Waffle", "0x%x %s", info->code, code);
 }
 
-static void
+static void NORETURN
 error_get_gl_symbol(const char *name)
 {
     error_printf("Wflinfo", "failed to get function pointer for %s", name);
@@ -552,9 +560,9 @@ print_extensions(bool use_stringi)
     printf("\n");
 }
 
-static struct {
+static const struct {
     GLint flag;
-    char *str;
+    const char *str;
 } context_flags[] = {
     { GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT, "FORWARD_COMPATIBLE" },
     { GL_CONTEXT_FLAG_DEBUG_BIT, "DEBUG" },
@@ -574,12 +582,12 @@ print_context_flags(void)
         return;
     }
 
-    if (context_flags == 0) {
+    if (gl_context_flags == 0) {
         printf(" 0x0\n");
         return;
     }
 
-    for (int i = 0; i < ARRAY_SIZE(context_flags); i++) {
+    for (unsigned i = 0; i < ARRAY_SIZE(context_flags); i++) {
         if ((context_flags[i].flag & gl_context_flags) != 0) {
             printf(" %s", context_flags[i].str);
             gl_context_flags = gl_context_flags & ~context_flags[i].flag;
@@ -606,7 +614,7 @@ json_print_extensions(bool use_stringi)
         if (glGetError() != GL_NO_ERROR) {
             printf("        \"WFLINFO_GL_ERROR\"");
         } else {
-            for (int i = 0; i < count; i++) {
+            for (GLint i = 0; i < count; i++) {
                 ext = (const char *) glGetStringi(GL_EXTENSIONS, i);
                 if (glGetError() != GL_NO_ERROR)
                     ext = "WFLINFO_GL_ERROR";
