@@ -392,7 +392,7 @@ gl_basic_draw__(void **state, struct gl_basic_draw_args__ args)
     ts->config = waffle_config_choose(ts->dpy, config_attrib_list);
     if (expect_error) {
         assert_true(ts->config == NULL);
-        assert_true(waffle_error_get_code() == expect_error);
+        assert_true((int32_t)waffle_error_get_code() == expect_error);
         return;
     } else if (ts->config == NULL) {
         switch (waffle_error_get_code()) {
@@ -402,6 +402,9 @@ gl_basic_draw__(void **state, struct gl_basic_draw_args__ args)
             // Assume that the native platform rejected the requested
             // config flavor.
             skip();
+	    // XXX: skip() is not annotated as noreturn, leading to compiler
+	    // warning about implicit fallthrough
+	    break;
         default:
             assert_true_with_wfl_error(ts->config);
         }
@@ -422,6 +425,9 @@ gl_basic_draw__(void **state, struct gl_basic_draw_args__ args)
             // Assume that the native platform rejected the requested
             // context flavor.
             skip();
+	    // XXX: skip() is not annotated as noreturn, leading to compiler
+	    // warning about implicit fallthrough
+	    break;
         default:
             assert_true_with_wfl_error(ts->ctx);
         }
@@ -460,6 +466,8 @@ gl_basic_draw__(void **state, struct gl_basic_draw_args__ args)
 	expected_version_str = "OpenGL ES ";
         break;
     default:
+        // Explicitly initialize, to appease GCC
+        expected_version_str = "";
         assert_true(0);
         break;
     }
@@ -1075,6 +1083,12 @@ static const char *usage_message =
 #define NORETURN
 #endif
 
+#if defined(__GNUC__)
+#define PRINTFLIKE(f, a) __attribute__((format(gnu_printf, f, a)))
+#else
+#define PRINTFLIKE(f, a)
+#endif
+
 static void NORETURN
 write_usage_and_exit(FILE *f, int exit_code)
 {
@@ -1092,8 +1106,10 @@ static const struct option get_opts[] = {
     { .name = "help",           .has_arg = no_argument,           .val = OPT_HELP },
 };
 
-static void NORETURN
+// clang-format off
+static void NORETURN PRINTFLIKE(1, 2)
 usage_error_printf(const char *fmt, ...)
+// clang-format on
 {
     fprintf(stderr, "gl_basic_test usage error: ");
 
